Security Advisories (2)
CVE-2015-3451 (2015-04-23)

The _clone function does not properly set the expand_entities option, which allows remote attackers to conduct XML external entity (XXE) attacks via crafted XML data to the (1) new or (2) load_xml function.

CVE-2017-10672 (2015-04-23)

Use-after-free in the XML-LibXML module through 2.0129 for Perl allows remote attackers to execute arbitrary code by controlling the arguments to a replaceChild call.

NAME

XML::LibXML::Text - The DOM Text Node Class

SYNOPSIS

use XML::LibXML::Text;

$node = XML::LibXML::Text->new( $content ) 
$node->setData( $text_content );

DESCRIPTION

Methods

new

The constuctor of the class. It creates an unbound text node.

setData

This function sets or replaces text content to a node. The node has to be of the type "text", "cdata" (not supported yet) or "comment".

SEE ALSO

XML::LibXML, XML::LibXML::Node, XML::LibXML::Element, XML::LibXML::Document, XML::LibXML::Comment, XML::LibXML::DocumentFragment

VERSION

0.95